==> ec2-0.25.1-sources.jar: software/amazon/awscdk/services/ec2/CfnVPC.java <==
package software.amazon.awscdk.services.ec2;

/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpc.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.15 (build e429c41)", date = "2019-03-05T00:09:22.935Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ec2.$Module.class, fqn = "@aws-cdk/aws-ec2.CfnVPC")
public class CfnVPC extends software.amazon.awscdk.Resource {
    protected CfnVPC(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    static {
        RESOURCE_TYPE_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.ec2.CfnVPC.class, "resourceTypeName", java.lang.String.class);
    }
    /**
     * Creates a new ``AWS::EC2::VPC``.
     * @param scope scope in which this resource is defined
     * @param id scoped id of the resource
     * @param props resource properties
     */
    public CfnVPC(final software.amazon.awscdk.Construct scope, final java.lang.String id, final software.amazon.awscdk.services.ec2.CfnVPCProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(scope, "scope is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(id, "id is required"))), java.util.stream.Stream.of(java.util.Objects.requireNonNull(props, "props is required"))).toArray());
    }

    @Override
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties(final java.lang.Object properties) {
        return this.jsiiCall("renderProperties", java.util.Map.class, java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required")).toArray());
    }
    /**
     * The CloudFormation resource type name for this resource class.
     */
    public final static java.lang.String RESOURCE_TYPE_NAME;

    public software.amazon.awscdk.services.ec2.CfnVPCProps getPropertyOverrides() {
        return this.jsiiGet("propertyOverrides", software.amazon.awscdk.services.ec2.CfnVPCProps.class);
    }

    /**
     * The ``TagManager`` handles setting, removing and formatting tags
     * 
     * Tags should be managed either passing them as properties during
     * initiation or by calling methods on this object. If both techniques are
     * used only the tags from the TagManager will be used. ``Tag`` (aspect)
     * will use the manager.
     */
    public software.amazon.awscdk.TagManager getTags() {
        return this.jsiiGet("tags", software.amazon.awscdk.TagManager.class);
    }

    /**
     * @cloudformation_attribute CidrBlock
     */
    public java.lang.String getVpcCidrBlock() {
        return this.jsiiGet("vpcCidrBlock", java.lang.String.class);
    }

    /**
     * @cloudformation_attribute CidrBlockAssociations
     */
    public java.util.List<java.lang.String> getVpcCidrBlockAssociations() {
        return this.jsiiGet("vpcCidrBlockAssociations", java.util.List.class);
    }

    /**
     * @cloudformation_attribute DefaultNetworkAcl
     */
    public java.lang.String getVpcDefaultNetworkAcl() {
        return this.jsiiGet("vpcDefaultNetworkAcl", java.lang.String.class);
    }

    /**
     * @cloudformation_attribute DefaultSecurityGroup
     */
    public java.lang.String getVpcDefaultSecurityGroup() {
        return this.jsiiGet("vpcDefaultSecurityGroup", java.lang.String.class);
    }

    public java.lang.String getVpcId() {
        return this.jsiiGet("vpcId", java.lang.String.class);
    }

    /**
     * @cloudformation_attribute Ipv6CidrBlocks
     */
    public java.util.List<java.lang.String> getVpcIpv6CidrBlocks() {
        return this.jsiiGet("vpcIpv6CidrBlocks", java.util.List.class);
    }
}

==> ec2-0.26.0-sources.jar: software/amazon/awscdk/services/ec2/CfnVPC.java <==
package software.amazon.awscdk.services.ec2;

/**
 * @cloudformationResource AWS::EC2::VPC
 * A CloudFormation `AWS::EC2::VPC`
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-vpc.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.15 (build e429c41)", date = "2019-03-20T12:57:55.081Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ec2.$Module.class, fqn = "@aws-cdk/aws-ec2.CfnVPC")
public class CfnVPC extends software.amazon.awscdk.CfnResource {
    protected CfnVPC(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    static {
        RESOURCE_TYPE_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.ec2.CfnVPC.class, "resourceTypeName", java.lang.String.class);
    }
    /**
     * Create a new `AWS::EC2::VPC`.
     * @param scope - scope in which this resource is defined
     * @param id - scoped id of the resource
     * @param props - resource properties
     */
    public CfnVPC(final software.amazon.awscdk.Construct scope, final java.lang.String id, final software.amazon.awscdk.services.ec2.CfnVPCProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(scope, "scope is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(id, "id is required"))), java.util.stream.Stream.of(java.util.Objects.requireNonNull(props, "props is required"))).toArray());
    }

    @Override
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties(final java.lang.Object properties) {
        return this.jsiiCall("renderProperties", java.util.Map.class, java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required")).toArray());
    }
    /**
     * The CloudFormation resource type name for this resource class.
     */
    public final static java.lang.String RESOURCE_TYPE_NAME;

    public software.amazon.awscdk.services.ec2.CfnVPCProps getPropertyOverrides() {
        return this.jsiiGet("propertyOverrides", software.amazon.awscdk.services.ec2.CfnVPCProps.class);
    }

    /**
     * The `TagManager` handles setting, removing and formatting tags
     * 
     * Tags should be managed either passing them as properties during
     * initiation or by calling methods on this object. If both techniques are
     * used only the tags from the TagManager will be used. `Tag` (aspect)
     * will use the manager.
     */
    public software.amazon.awscdk.TagManager getTags() {
        return this.jsiiGet("tags", software.amazon.awscdk.TagManager.class);
    }

    /**
     * @cloudformationAttribute CidrBlock
     */
    public java.lang.String getVpcCidrBlock() {
        return this.jsiiGet("vpcCidrBlock", java.lang.String.class);
    }

    /**
     * @cloudformationAttribute CidrBlockAssociations
     */
    public java.util.List<java.lang.String> getVpcCidrBlockAssociations() {
        return this.jsiiGet("vpcCidrBlockAssociations", java.util.List.class);
    }

    /**
     * @cloudformationAttribute DefaultNetworkAcl
     */
    public java.lang.String getVpcDefaultNetworkAcl() {
        return this.jsiiGet("vpcDefaultNetworkAcl", java.lang.String.class);
    }

    /**
     * @cloudformationAttribute DefaultSecurityGroup
     */
    public java.lang.String getVpcDefaultSecurityGroup() {
        return this.jsiiGet("vpcDefaultSecurityGroup", java.lang.String.class);
    }

    public java.lang.String getVpcId() {
        return this.jsiiGet("vpcId", java.lang.String.class);
    }

    /**
     * @cloudformationAttribute Ipv6CidrBlocks
     */
    public java.util.List<java.lang.String> getVpcIpv6CidrBlocks() {
        return this.jsiiGet("vpcIpv6CidrBlocks", java.util.List.class);
    }
}
